@@ -25,7 +25,7 @@ utils::globalVariables(c('snclq','value','everything'))
 # Method to save a list of Metric objects to disk.
 #
 # Internet access methods come from the RCurl package which is loaded by the
-# IRISSeismic package which is required by the siesmicMetrics package.
+# IRISSeismic package which is required by the seismicMetrics package.
 ################################################################################
 
 saveMetricList <- function(metricList,
@@ -769,6 +769,7 @@ if (!isGeneric("getGeneralValueMetrics")) {
 getGeneralValueMetrics.IrisClient <- function(obj, network, station, location, channel,
                                              starttime, endtime, metricName, constraint="", url=NULL) {
 
+
   # Sanity check
   if (length(metricName) > 1) {
     stop(paste('metricName should be a single string with comma separated metric names, not a vector of metric names.'))
@@ -832,10 +833,6 @@ getGeneralValueMetrics.IrisClient <- function(obj, network, station, location, c
   # Create the BSS URL
   url2 <- createBssUrl(obj, network, station, location, channel, starttime, endtime, metricName, constraint, url) 
 
-  if (is.null(url)) {
-    url <- paste0(strsplit(url2,"\\?")[[1]][1],"?")
-  }
-
   # Get data from the measurements webservice
   # NOTE:  Use RCurl::getURL to return data as character.
   h <-  RCurl::basicTextGatherer()
