@@ -30,7 +30,7 @@ sampleRateRespMetric <- function(st, resp_pct=15, norm_freq=NULL, evalresp=NULL)
     if (!inherits(iris,"IrisClient")) {
        iris <- new("IrisClient") # defaults to fdsnws 
     }
-    if (is.null(norm_freq)) { # if metadata sample rate or normalized frequency not provided, go to IRIS web services
+    if (is.null(norm_freq)) { # if metadata sample rate or normalized frequency not provided, go to EarthScope web services
        av <- getChannel(iris,network,station,location,channel,st@traces[[1]]@stats@starttime, st@traces[[1]]@stats@endtime)
        norm_freq <- av$scalefreq
     }
@@ -60,7 +60,7 @@ sampleRateRespMetric <- function(st, resp_pct=15, norm_freq=NULL, evalresp=NULL)
   colClasses <- c("character","character","character")
 
   # query evalresp
-  #   If ISPAQ calls this function but lacks access to evalresp from IRIS web services, it will 
+  #   If ISPAQ calls this function but lacks access to evalresp from EarthScope web services, it will 
   #   generate equivalent response values by running evalresp on a local RESP file and pass this 
   #   information using the "evalresp" argument to the sampleRateRespMetric function.  When this is 
   #   not the case, this argument will be NULL.
